#ifndef _BIOSIO_H
#define _BIOSIO_H
/*
 *	$RCSfile: biosio.h $		$Revision: 1.0 $
 *
 *	Bios level interface functions header
 *
 * 	Graham E. Kinns		Borland C++ 4.01 (patched)
 *
 *	$Log: biosio.h $
 *		Revision 1.0  1995/10/30  21:07:14  Graham
 *		Initial revision
 *
 */
#ifndef _GLOBAL_H
#  include "global.h"
#endif  /*  _GLOBAL_H  */

/*  list of constants to check passed parameters  */
#define BIOS_MAX_DRIVE 3
#define BIOS_MAX_SIDE 1
#define BIOS_MAX_TRACK 83
#define BIOS_MAX_SECTOR 20

#define BIOS_MAX_RETRIES 3  /*  Number of times to attempt to re-read sector  */

/*  returned error codes from bios disk int 13h functions  */
#define BIOS_ERR_BAD_PARAM 0x01
#define BIOS_ERR_ADDR_MARKNOTFOUND 0x02
#define BIOS_ERR_WRITE_PROTECTED 0x03
#define BIOS_ERR_SECTOR_NOT_FOUND 0x04
#define BIOS_ERR_DISK_CHANGE 0x06

#define BIOS_DBT_INTERRUPT_VECTOR 0x1e
#define BIOS_DBT_SIZE 11
#define BIOS_DBT_SECTOR_CODE_OFFSET 3
#define BIOS_DBT_MAX_SECTOR_OFFSET 4

typedef struct biosdbt
{

	Word	orig_segment;
	Word	orig_offset;

	Byte	table[ BIOS_DBT_SIZE ];

} BiosDBT;

typedef struct bioserrordesc
{

	Byte		code;		/*  Code returned  */
	const char	*string;	/*  Description string  */

} BiosErrorDescription;

/*  Returns true if ( w1+w2 > 0xffff )  */
#define WORD_WRAPS_ROUND( w1, w2 ) (( (Word) ( (w1) + (w2) )) < (Word) (w2) )

/*
 *   Determines whether a given buffer at ptr, size len, crosses a DMA page
 *   boundary ( Linear address 0x?0000 )
 */
#define BIOS_BUFFER_CROSSES_DMA_BOUNDARY( ptr, len ) \
	WORD_WRAPS_ROUND( (Word) ( FARPTR_TO_DWORD( ptr ) & 0x0000ffffUL ), \
					  (Word) ( len ) )

/*  function prototypes from biosio.c  */
Byte	bios_reset_drive ( Byte drive );
Byte	bios_get_last_error ( Byte drive );
Byte	bios_read_sectors ( Byte drive, Byte track, Byte side,
					 Byte start_sector, Byte num_sectors,
					 MemPtr sector_buf );
Byte	bios_write_sectors ( Byte drive, Byte track, Byte side,
					  Byte start_sector, Byte num_sectors,
					  MemPtr sector_buf );
Byte	bios_format_track ( Byte drive, Byte track, Byte side, Byte num_sectors,
				MemPtr addr_field_buf );
Byte	bios_get_disk_type ( Byte drive );

Bool	bios_hook_dbt ( BiosDBT *dbt );
Bool	bios_restore_dbt ( BiosDBT *dbt );
const char	*bios_error ( Byte drive, Byte error_code );

#endif	/*  _BIOSIO_H  */

